@@ -310,7 +310,8 @@ class ImdbLookup(object):
             return fake_entry['imdb_id']
 
     @plugin.internet(log)
-    def lookup(self, entry, search_allowed=True):
+    @with_session
+    def lookup(self, entry, search_allowed=True, session=None):
         """
         Perform imdb lookup for entry.
 
@@ -330,115 +331,105 @@ class ImdbLookup(object):
         else:
             raise plugin.PluginError('looking up IMDB for entry failed, no title, imdb_url or imdb_id passed.')
 
-        session = Session()
+        # if imdb_id is included, build the url.
+        if entry.get('imdb_id', eval_lazy=False) and not entry.get('imdb_url', eval_lazy=False):
+            entry['imdb_url'] = make_url(entry['imdb_id'])
 
-        try:
-            # entry sanity checks
-            for field in ['imdb_votes', 'imdb_score']:
-                if entry.get(field, eval_lazy=False):
-                    value = entry[field]
-                    if not isinstance(value, (int, float)):
-                        raise plugin.PluginError('Entry field %s should be a number!' % field)
+        # make sure imdb url is valid
+        if entry.get('imdb_url', eval_lazy=False):
+            imdb_id = extract_id(entry['imdb_url'])
+            if imdb_id:
+                entry['imdb_url'] = make_url(imdb_id)
+            else:
+                log.debug('imdb url %s is invalid, removing it' % entry['imdb_url'])
+                del(entry['imdb_url'])
 
-            # if imdb_id is included, build the url.
-            if entry.get('imdb_id', eval_lazy=False) and not entry.get('imdb_url', eval_lazy=False):
-                entry['imdb_url'] = make_url(entry['imdb_id'])
-
-            # make sure imdb url is valid
-            if entry.get('imdb_url', eval_lazy=False):
-                imdb_id = extract_id(entry['imdb_url'])
-                if imdb_id:
-                    entry['imdb_url'] = make_url(imdb_id)
+        # no imdb_url, check if there is cached result for it or if the
+        # search is known to fail
+        if not entry.get('imdb_url', eval_lazy=False):
+            result = session.query(SearchResult).filter(SearchResult.title == entry['title']).first()
+            if result:
+                # TODO: 1.2 this should really be checking task.options.retry
+                if result.fails and not manager.options.execute.retry:
+                    # this movie cannot be found, not worth trying again ...
+                    log.debug('%s will fail lookup' % entry['title'])
+                    raise plugin.PluginError('IMDB lookup failed for %s' % entry['title'])
                 else:
-                    log.debug('imdb url %s is invalid, removing it' % entry['imdb_url'])
-                    del(entry['imdb_url'])
+                    if result.url:
+                        log.trace('Setting imdb url for %s from db' % entry['title'])
+                        entry['imdb_id'] = result.imdb_id
+                        entry['imdb_url'] = result.url
 
-            # no imdb_url, check if there is cached result for it or if the
-            # search is known to fail
-            if not entry.get('imdb_url', eval_lazy=False):
-                result = session.query(SearchResult).\
-                    filter(SearchResult.title == entry['title']).first()
-                if result:
-                    # TODO: 1.2 this should really be checking task.options.retry
-                    if result.fails and not manager.options.execute.retry:
-                        # this movie cannot be found, not worth trying again ...
-                        log.debug('%s will fail lookup' % entry['title'])
-                        raise plugin.PluginError('IMDB lookup failed for %s' % entry['title'])
-                    else:
-                        if result.url:
-                            log.trace('Setting imdb url for %s from db' % entry['title'])
-                            entry['imdb_url'] = result.url
+        movie = None
 
-            # no imdb url, but information required, try searching
-            if not entry.get('imdb_url', eval_lazy=False) and search_allowed:
-                log.verbose('Searching from imdb `%s`' % entry['title'])
-
-                search = ImdbSearch()
-                search_name = entry.get('movie_name', entry['title'], eval_lazy=False)
-                search_result = search.smart_match(search_name)
-                if search_result:
-                    entry['imdb_url'] = search_result['url']
-                    # store url for this movie, so we don't have to search on
-                    # every run
-                    result = SearchResult(entry['title'], entry['imdb_url'])
-                    session.add(result)
-                    log.verbose('Found %s' % (entry['imdb_url']))
-                else:
-                    log_once('IMDB lookup failed for %s' % entry['title'], log, logging.WARN)
-                    # store FAIL for this title
-                    result = SearchResult(entry['title'])
-                    result.fails = True
-                    session.add(result)
-                    raise plugin.PluginError('Title `%s` lookup failed' % entry['title'])
+        # no imdb url, but information required, try searching
+        if not entry.get('imdb_url', eval_lazy=False) and search_allowed:
+            log.verbose('Searching from imdb `%s`' % entry['title'])
+            search = ImdbSearch()
+            search_name = entry.get('movie_name', entry['title'], eval_lazy=False)
+            search_result = search.smart_match(search_name)
+            if search_result:
+                entry['imdb_url'] = search_result['url']
+                # store url for this movie, so we don't have to search on
+                # every run
+                result = SearchResult(entry['title'], entry['imdb_url'])
+                session.add(result)
+                session.commit()
+                log.verbose('Found %s' % (entry['imdb_url']))
+            else:
+                log_once('IMDB lookup failed for %s' % entry['title'], log, logging.WARN)
+                # store FAIL for this title
+                result = SearchResult(entry['title'])
+                result.fails = True
+                session.add(result)
+                session.commit()
+                raise plugin.PluginError('Title `%s` lookup failed' % entry['title'])
 
             # check if this imdb page has been parsed & cached
             movie = session.query(Movie).filter(Movie.url == entry['imdb_url']).first()
 
-            # determine whether or not movie details needs to be parsed
-            req_parse = False
-            if not movie:
-                req_parse = True
-            elif movie.expired:
-                req_parse = True
+            # If we have a movie from cache, we are done
+            if movie and not movie.expired:
+                entry.update_using_map(self.field_map, movie)
+                return
 
-            if req_parse:
-                if movie is not None:
-                    if movie.expired:
-                        log.verbose('Movie `%s` details expired, refreshing ...' % movie.title)
-                    # Remove the old movie, we'll store another one later.
-                    session.query(MovieLanguage).filter(MovieLanguage.movie_id == movie.id).delete()
-                    session.query(Movie).filter(Movie.url == entry['imdb_url']).delete()
-
-                # search and store to cache
-                if 'title' in entry:
-                    log.verbose('Parsing imdb for `%s`' % entry['title'])
-                else:
-                    log.verbose('Parsing imdb for `%s`' % entry['imdb_id'])
-                try:
-                    movie = self._parse_new_movie(entry['imdb_url'], session)
-                except UnicodeDecodeError:
-                    log.error('Unable to determine encoding for %s. Installing chardet library may help.' %
-                              entry['imdb_url'])
-                    # store cache so this will not be tried again
-                    movie = Movie()
-                    movie.url = entry['imdb_url']
-                    session.add(movie)
-                    raise plugin.PluginError('UnicodeDecodeError')
-                except ValueError as e:
-                    # TODO: might be a little too broad catch, what was this for anyway? ;P
-                    if manager.options.debug:
-                        log.exception(e)
-                    raise plugin.PluginError('Invalid parameter: %s' % entry['imdb_url'], log)
-
-            for att in ['title', 'score', 'votes', 'year', 'genres', 'languages', 'actors', 'directors', 'mpaa_rating']:
-                log.trace('movie.%s: %s' % (att, getattr(movie, att)))
-
-            # store to entry
-            entry.update_using_map(self.field_map, movie)
-        finally:
-            log.trace('committing session')
+        # Movie was not found in cache, or was expired
+        if movie is not None:
+            if movie.expired:
+                log.verbose('Movie `%s` details expired, refreshing ...' % movie.title)
+            # Remove the old movie, we'll store another one later.
+            session.query(MovieLanguage).filter(MovieLanguage.movie_id == movie.id).delete()
+            session.query(Movie).filter(Movie.url == entry['imdb_url']).delete()
             session.commit()
-            session.close()
+
+        # search and store to cache
+        if 'title' in entry:
+            log.verbose('Parsing imdb for `%s`' % entry['title'])
+        else:
+            log.verbose('Parsing imdb for `%s`' % entry['imdb_id'])
+        try:
+            movie = self._parse_new_movie(entry['imdb_url'], session)
+        except UnicodeDecodeError:
+            log.error('Unable to determine encoding for %s. Installing chardet library may help.' %
+                      entry['imdb_url'])
+            # store cache so this will not be tried again
+            movie = Movie()
+            movie.url = entry['imdb_url']
+            session.add(movie)
+            session.commit()
+            raise plugin.PluginError('UnicodeDecodeError')
+        except ValueError as e:
+            # TODO: might be a little too broad catch, what was this for anyway? ;P
+            if manager.options.debug:
+                log.exception(e)
+            raise plugin.PluginError('Invalid parameter: %s' % entry['imdb_url'], log)
+
+        for att in ['title', 'score', 'votes', 'year', 'genres', 'languages', 'actors', 'directors', 'mpaa_rating']:
+            log.trace('movie.%s: %s' % (att, getattr(movie, att)))
+
+        # store to cache and entry
+        session.commit()
+        entry.update_using_map(self.field_map, movie)
 
     def _parse_new_movie(self, imdb_url, session):
         """
